==> haskell-tostring-0.2.1.1-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tostring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-PJJBLO4HhyKuGqF3I67gs
key:                  tostring-0.2.1.1-PJJBLO4HhyKuGqF3I67gs
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  a3da21733d0e9397368f86a4f2956772
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-PJJBLO4HhyKuGqF3I67gs
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-LnNRkIvaVf25YvATjz2MZ1
    text-2.0.2 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tostring-0.2.1.1-171-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tostring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-DE3bx0S5bFi2b9MFjT98Bb
key:                  tostring-0.2.1.1-DE3bx0S5bFi2b9MFjT98Bb
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  93cc67ef170e89f78190593f7ca66718
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-DE3bx0S5bFi2b9MFjT98Bb
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-8vz9c08oERN6HaPlnW3IdE
    text-2.0.2 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
